package com.fs.company.service;

import com.fs.company.domain.CompanyPost;

import java.util.List;

/**
 * 岗位信息Service接口
 * 
 * @author fs
 * @date 2021-05-25
 */
public interface ICompanyPostService 
{
    /**
     * 查询岗位信息
     * 
     * @param postId 岗位信息ID
     * @return 岗位信息
     */
    public CompanyPost selectCompanyPostById(Long postId);

    /**
     * 查询岗位信息列表
     * 
     * @param companyPost 岗位信息
     * @return 岗位信息集合
     */
    public List<CompanyPost> selectCompanyPostList(CompanyPost companyPost);

    /**
     * 新增岗位信息
     * 
     * @param companyPost 岗位信息
     * @return 结果
     */
    public int insertCompanyPost(CompanyPost companyPost);

    /**
     * 修改岗位信息
     * 
     * @param companyPost 岗位信息
     * @return 结果
     */
    public int updateCompanyPost(CompanyPost companyPost);

    /**
     * 批量删除岗位信息
     * 
     * @param postIds 需要删除的岗位信息ID
     * @return 结果
     */
    public int deleteCompanyPostByIds(Long[] postIds);

    /**
     * 删除岗位信息信息
     * 
     * @param postId 岗位信息ID
     * @return 结果
     */
    public int deleteCompanyPostById(Long postId);

    int checkPostCodeUnique(CompanyPost post);

    List<Integer> selectPostListByUserId(Long userId);

    List<String> selectPostNameListByUserId(Long userId);
}
